@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,6 +22,11 @@ import tokenize
 import ast
 import sys
 
+try:
+    ast.AsyncFunctionDef    # __IGNORE_EXCEPTION__
+except AttributeError:
+    ast.AsyncFunctionDef = ast.FunctionDef
+
 
 class DocStyleContext(object):
     """
@@ -35,7 +40,11 @@ class DocStyleContext(object):
         @param startLine line number the context starts in the source (integer)
         @param contextType type of the context object (string)
         """
-        if isinstance(source, str):
+        if sys.version_info[0] == 2:
+            stringTypes = (str, unicode)        # __IGNORE_WARNING__
+        else:
+            stringTypes = str
+        if isinstance(source, stringTypes):
             self.__source = source.splitlines(True)
         else:
             self.__source = source[:]
@@ -323,8 +332,15 @@ class DocStyleChecker(object):
             # don't do anything, if no codes were selected
             return
         
+        source = "".join(self.__source)
+        # Check type for py2: if not str it's unicode
+        if sys.version_info[0] == 2:
+            try:
+                source = source.encode('utf-8')
+            except UnicodeError:
+                pass
         try:
-            compile(''.join(self.__source), '', 'exec', ast.PyCF_ONLY_AST)
+            compile(source, self.__filename, 'exec', ast.PyCF_ONLY_AST)
         except (SyntaxError, TypeError):
             self.__reportInvalidSyntax()
             return
@@ -1071,7 +1087,8 @@ class DocStyleChecker(object):
         except (SyntaxError, TypeError):
             return
         if (isinstance(tree, ast.Module) and len(tree.body) == 1 and
-                isinstance(tree.body[0], ast.FunctionDef)):
+                isinstance(tree.body[0],
+                           (ast.FunctionDef, ast.AsyncFunctionDef))):
             functionDef = tree.body[0]
             argNames, kwNames = self.__getArgNames(functionDef)
             if "self" in argNames:
@@ -1263,3 +1280,6 @@ class DocStyleChecker(object):
                 if firstWord != 'public':
                     self.__error(docstringContext.start() + lineNumber, 0,
                                  "D232", 'public')
+
+#
+# eflag: noqa = M702
